@@ -10,7 +10,7 @@ use Log::Any '$log';
 use Time::HiRes 'time';
 
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 
 my $SEPARATOR_ID_ACK = '#';
@@ -99,6 +99,7 @@ sub setup_stomp_clients {
             sub {
                 my (undef, $header, undef) = @_;
                 $log->debug("$id STOMP ERROR received: '$header->{message}'.");
+                $self->event('ANY_ERROR', $header->{message}, $id);
             }
         );
 
@@ -339,4 +340,8 @@ sub on_subscribed {
     return shift->reg_cb('ANY_SUBSCRIBED', shift);
 }
 
+sub on_error {
+    return shift->reg_cb('ANY_ERROR', shift);
+}
+
 1;
